@@ -5,6 +5,7 @@ from __future__ import annotations
 import enum
 import re
 import sys
+import warnings
 from functools import lru_cache
 from typing import TYPE_CHECKING, Any, Callable, Match, Pattern, Sequence
 
@@ -13,7 +14,7 @@ from markupsafe import Markup
 from mkdocstrings.loggers import get_logger
 
 if TYPE_CHECKING:
-    from griffe.dataclasses import Alias, Function, Object
+    from griffe.dataclasses import Alias, Attribute, Function, Object
     from jinja2.runtime import Context
     from mkdocstrings.handlers.base import CollectorItem
 
@@ -103,14 +104,60 @@ def do_format_signature(
     template = env.get_template("signature.html")
     signature = template.render(context.parent, function=function)
     signature = _format_signature(callable_path, signature, line_length)
-    signature = str(env.filters["highlight"](signature, language="python", inline=False))
-    return signature
+    return str(
+        env.filters["highlight"](
+            signature,
+            language="python",
+            inline=False,
+            classes=["doc-signature"],
+        ),
+    )
+
+
+@pass_context
+def do_format_attribute(
+    context: Context,
+    attribute_path: Markup,
+    attribute: Attribute,
+    line_length: int,
+    *,
+    crossrefs: bool = False,  # noqa: ARG001
+) -> str:
+    """Format an attribute using Black.
+
+    Parameters:
+        attribute_path: The path of the callable we render the signature of.
+        attribute: The attribute we render the signature of.
+        line_length: The line length to give to Black.
+        crossrefs: Whether to cross-reference types in the signature.
+
+    Returns:
+        The same code, formatted.
+    """
+    env = context.environment
+    annotations = context.parent["config"]["show_signature_annotations"]
+
+    signature = str(attribute_path).strip()
+    if annotations and attribute.annotation:
+        signature += f": {attribute.annotation}"
+    if attribute.value:
+        signature += f" = {attribute.value}"
+
+    signature = do_format_code(signature, line_length)
+    return str(
+        env.filters["highlight"](
+            Markup.escape(signature),
+            language="python",
+            inline=False,
+            classes=["doc-signature"],
+        ),
+    )
 
 
 def do_order_members(
     members: Sequence[Object | Alias],
     order: Order,
-    members_list: list[str] | None,
+    members_list: bool | list[str] | None,
 ) -> Sequence[Object | Alias]:
     """Order members given an ordering method.
 
@@ -122,7 +169,7 @@ def do_order_members(
     Returns:
         The same members, ordered.
     """
-    if members_list:
+    if isinstance(members_list, list) and members_list:
         sorted_members = []
         members_dict = {member.name: member for member in members}
         for name in members_list:
@@ -132,8 +179,17 @@ def do_order_members(
     return sorted(members, key=order_map[order])
 
 
+@lru_cache
+def _warn_crossref() -> None:
+    warnings.warn(
+        "The `crossref` filter is deprecated and will be removed in a future version",
+        DeprecationWarning,
+        stacklevel=1,
+    )
+
+
 def do_crossref(path: str, *, brief: bool = True) -> Markup:
-    """Filter to create cross-references.
+    """Deprecated. Filter to create cross-references.
 
     Parameters:
         path: The path to link to.
@@ -142,14 +198,24 @@ def do_crossref(path: str, *, brief: bool = True) -> Markup:
     Returns:
         Markup text.
     """
+    _warn_crossref()
     full_path = path
     if brief:
         path = full_path.split(".")[-1]
     return Markup("<span data-autorefs-optional-hover={full_path}>{path}</span>").format(full_path=full_path, path=path)
 
 
+@lru_cache
+def _warn_multi_crossref() -> None:
+    warnings.warn(
+        "The `multi_crossref` filter is deprecated and will be removed in a future version",
+        DeprecationWarning,
+        stacklevel=1,
+    )
+
+
 def do_multi_crossref(text: str, *, code: bool = True) -> Markup:
-    """Filter to create cross-references.
+    """Deprecated. Filter to create cross-references.
 
     Parameters:
         text: The text to scan.
@@ -158,6 +224,7 @@ def do_multi_crossref(text: str, *, code: bool = True) -> Markup:
     Returns:
         Markup text.
     """
+    _warn_multi_crossref()
     group_number = 0
     variables = {}
 
@@ -175,6 +242,28 @@ def do_multi_crossref(text: str, *, code: bool = True) -> Markup:
     return Markup(text).format(**variables)
 
 
+def do_split_path(path: str, full_path: str) -> list[tuple[str, str]]:
+    """Split object paths for building cross-references.
+
+    Parameters:
+        path: The path to split.
+
+    Returns:
+        A list of pairs (title, full path).
+    """
+    if "." not in path:
+        return [(path, full_path)]
+    pairs = []
+    full_path = ""
+    for part in path.split("."):
+        if full_path:
+            full_path += f".{part}"
+        else:
+            full_path = part
+        pairs.append((part, full_path))
+    return pairs
+
+
 def _keep_object(name: str, filters: Sequence[tuple[Pattern, bool]]) -> bool:
     keep = None
     rules = set()
@@ -195,7 +284,8 @@ def do_filter_objects(
     objects_dictionary: dict[str, Object | Alias],
     *,
     filters: Sequence[tuple[Pattern, bool]] | None = None,
-    members_list: list[str] | None = None,
+    members_list: bool | list[str] | None = None,
+    inherited_members: bool | list[str] = False,
     keep_no_docstrings: bool = True,
 ) -> list[Object | Alias]:
     """Filter a dictionary of objects based on their docstrings.
@@ -208,31 +298,49 @@ def do_filter_objects(
         members_list: An optional, explicit list of members to keep.
             When given and empty, return an empty list.
             When given and not empty, ignore filters and docstrings presence/absence.
+        inherited_members: Whether to keep inherited members or exclude them.
         keep_no_docstrings: Whether to keep objects with no/empty docstrings (recursive check).
 
     Returns:
         A list of objects.
     """
-    # no members
-    if members_list is False or members_list == []:
-        return []
+    inherited_members_specified = False
+    if inherited_members is True:
+        # Include all inherited members.
+        objects = list(objects_dictionary.values())
+    elif inherited_members is False:
+        # Include no inherited members.
+        objects = [obj for obj in objects_dictionary.values() if not obj.inherited]
+    else:
+        # Include specific inherited members.
+        inherited_members_specified = True
+        objects = [
+            obj for obj in objects_dictionary.values() if not obj.inherited or obj.name in set(inherited_members)
+        ]
 
-    objects = list(objects_dictionary.values())
-
-    # all members
     if members_list is True:
+        # Return all pre-selected members.
         return objects
 
-    # list of members
-    if members_list is not None:
-        return [obj for obj in objects if obj.name in set(members_list)]
+    if members_list is False or members_list == []:
+        # Return selected inherited members, if any.
+        return [obj for obj in objects if obj.inherited]
 
-    # none, use filters and docstrings
+    if members_list is not None:
+        # Return selected members (keeping any pre-selected inherited members).
+        return [
+            obj for obj in objects if obj.name in set(members_list) or (inherited_members_specified and obj.inherited)
+        ]
+
+    # Use filters and docstrings.
     if filters:
-        objects = [obj for obj in objects if _keep_object(obj.name, filters)]
+        objects = [
+            obj for obj in objects if _keep_object(obj.name, filters) or (inherited_members_specified and obj.inherited)
+        ]
     if keep_no_docstrings:
         return objects
-    return [obj for obj in objects if obj.has_docstrings]
+
+    return [obj for obj in objects if obj.has_docstrings or (inherited_members_specified and obj.inherited)]
 
 
 @lru_cache(maxsize=1)
